@@ -5,7 +5,10 @@ from tnorm.TN_wrapper import TN_wrapper as load
 
 import tnorm.kernel
 import tnorm.extras
-#from tnorm.test import test
+from tnorm.test import test
+
+from tnorm.utilities.file_IO import save_file
+from tnorm.utilities.file_IO import open_file
 #import tnorm.GUI
 
 
