@@ -1,23 +1,12 @@
-#from sympy import Matrix
-#from sympy import Rational as QQ
+
+from .sage_types import Integer, QQ, Matrix
 
 
-#import imp
-#regina = imp.load_source('regina', '/Applications/SageMath/local/lib/python2.7/site-packages/sageRegina-5.1.5-py2.7.egg-info')
-
-from .sage_types import *
-
-
-
-### identify which cusp the given vertex of the given tetrahedron is in
-#def get_cusp_index(T,tet,vertex):
-#    return T.tetrahedron(int(tet)).vertex(int(vertex)).boundaryComponent().index()
 
 ### return True if vertex "vert" of tetrahedron "tet" is in given cusp
 def in_cusp(T,tet,vert,cusp):
-    return T.tetrahedron(int(tet)).vertex(int(vert)) == T.cusp(cusp).vertex()
+    return T.tetrahedron(int(tet)).vertex(int(vert)) == T.cusp(int(cusp)).vertex()
 
-#    return get_cusp_index(T,tet,vert)==cusp
 
 
 ### convert regina types (integers, rational, matrices) to sage types
@@ -25,7 +14,7 @@ def regina_to_sage_int(q):
     return Integer(q.longValue())
 
 def regina_to_sage_rat(q):
-    return QQ(q.numerator().longValue(),q.denominator().longValue())
+    return QQ((q.numerator().longValue(),q.denominator().longValue()))
 
 def regina_to_sage_mat(q):
     return Matrix([[regina_to_sage_int(q.entry(i,j)) for j in range(q.columns())] for i in range(q.rows())])
